@@ -16,11 +16,11 @@ pub use types::PipeFlags;
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 pub use types::PIPE_BUF;
 #[cfg(not(target_os = "wasi"))]
-pub use types::{DupFlags, MapFlags, ProtFlags, Tcflag, Termios, Winsize, ICANON};
+pub use types::{DupFlags, MapFlags, MprotectFlags, ProtFlags, Tcflag, Termios, Winsize, ICANON};
 #[cfg(any(target_os = "android", target_os = "linux"))]
-pub use types::{EventfdFlags, ReadWriteFlags, UserfaultfdFlags};
+pub use types::{EventfdFlags, MlockFlags, ReadWriteFlags, UserfaultfdFlags};
 
-use std::os::raw::c_int;
+use libc::c_int;
 
 #[cfg(not(target_os = "redox"))]
 pub(crate) const AT_FDCWD: c_int = libc::AT_FDCWD;
