@@ -4,13 +4,18 @@
 //!
 //! This uses raw pointers to locate and read the kernel-provided auxv array.
 #![allow(unsafe_code)]
-#![allow(non_snake_case)]
 
-use linux_raw_sys::general::{AT_HWCAP, AT_NULL, AT_PAGESZ};
+use super::super::elf::Elf_Phdr;
+use linux_raw_sys::general::{
+    AT_EXECFN, AT_HWCAP, AT_NULL, AT_PAGESZ, AT_PHDR, AT_PHENT, AT_PHNUM,
+};
 use linux_raw_sys::v5_4::general::{AT_HWCAP2, AT_SYSINFO_EHDR};
+use std::ffi::CStr;
+use std::mem::size_of;
 use std::os::raw::c_char;
-#[cfg(target_env = "gnu")]
+#[cfg(all(target_env = "gnu", not(target_vendor = "mustang")))]
 use std::os::raw::c_int;
+use std::slice;
 
 #[inline]
 pub(crate) fn page_size() -> usize {
@@ -23,6 +28,16 @@ pub(crate) fn linux_hwcap() -> (usize, usize) {
     (auxv.hwcap, auxv.hwcap2)
 }
 
+#[inline]
+pub(crate) fn linux_execfn() -> &'static CStr {
+    unsafe { CStr::from_ptr(auxv().execfn as *const c_char) }
+}
+
+#[inline]
+pub(in super::super) fn exe_phdrs() -> &'static [Elf_Phdr] {
+    unsafe { slice::from_raw_parts(AUXV.phdr as *const Elf_Phdr, AUXV.phnum) }
+}
+
 #[inline]
 pub(in super::super) fn sysinfo_ehdr() -> usize {
     auxv().sysinfo_ehdr
@@ -41,6 +56,9 @@ struct Auxv {
     hwcap: usize,
     hwcap2: usize,
     sysinfo_ehdr: usize,
+    phdr: usize,
+    phnum: usize,
+    execfn: usize,
 }
 
 /// Data obtained from the kernel-provided auxv array. This is initialized at
@@ -50,12 +68,15 @@ static mut AUXV: Auxv = Auxv {
     hwcap: 0,
     hwcap2: 0,
     sysinfo_ehdr: 0,
+    phdr: 0,
+    phnum: 0,
+    execfn: 0,
 };
 
 /// GLIBC passes argc, argv, and envp to functions in .init_array, as a
 /// non-standard extension. Use priority 99 so that we run before any
 /// normal user-defined constructor functions.
-#[cfg(target_env = "gnu")]
+#[cfg(all(target_env = "gnu", not(target_vendor = "mustang")))]
 #[used]
 #[link_section = ".init_array.00099"]
 static INIT_ARRAY: unsafe extern "C" fn(c_int, *mut *mut c_char, *mut *mut c_char) = {
@@ -71,7 +92,7 @@ static INIT_ARRAY: unsafe extern "C" fn(c_int, *mut *mut c_char, *mut *mut c_cha
 /// user-defined constructor functions.
 ///
 /// <https://refspecs.linuxbase.org/LSB_5.0.0/LSB-Core-generic/LSB-Core-generic/baselib---environ.html>
-#[cfg(not(target_env = "gnu"))]
+#[cfg(not(any(target_env = "gnu", target_vendor = "mustang")))]
 #[used]
 #[link_section = ".init_array.00099"]
 static INIT_ARRAY: unsafe extern "C" fn() = {
@@ -85,6 +106,13 @@ static INIT_ARRAY: unsafe extern "C" fn() = {
     function
 };
 
+/// On mustang, we export a function to be called during initialization.
+#[cfg(target_vendor = "mustang")]
+#[inline]
+pub(crate) unsafe fn init(envp: *mut *mut c_char) {
+    init_from_envp(envp);
+}
+
 /// # Safety
 ///
 /// This must be passed a pointer to the environment variable buffer
@@ -107,6 +135,10 @@ unsafe fn init_from_auxp(mut auxp: *const Elf_auxv_t) {
             AT_HWCAP => AUXV.hwcap = a_val,
             AT_HWCAP2 => AUXV.hwcap2 = a_val,
             AT_SYSINFO_EHDR => AUXV.sysinfo_ehdr = a_val,
+            AT_PHDR => AUXV.phdr = a_val,
+            AT_PHNUM => AUXV.phnum = a_val,
+            AT_PHENT => assert_eq!(a_val, size_of::<Elf_Phdr>()),
+            AT_EXECFN => AUXV.execfn = a_val,
             AT_NULL => break,
             _ => (),
         }
